/*______________________________________________________________________________

British Cohort Study BCS70
Required datasets (UKDS SN & DOI): 
bcs7072a (SN: 2666, http://doi.org/10.5255/UKDA-SN-2666-2)
f699b (SN: 2699, http://doi.org/10.5255/UKDA-SN-2699-4)
sn3723 (SN: 3723, http://doi.org/10.5255/UKDA-SN-3723-7)
______________________________________________________________________________*/


*Birth sweep data
use bcs7072a.dta, clear

*Merge with age 5 & 10 main survey data
merge 1:1 bcsid using f699b.dta, nogen // age 5 data
merge 1:1 bcsid using sn3723.dta, nogen // age 10 data



// NUMBER OF PREVIOUS LIVE BIRTHS
*number of live births previously had by mother of CM member: consider children who are still alive in 1970, those who died before 7 days and those who died after 7 days. In around 600 cases I get a different result from a0166 (which appears wrong)  
gen num_livebirths=0
foreach i in 055 061 067 073 079 085 091 102 108 114 120 126 132 138 149 155 161 {
replace num_livebirths=num_livebirths+1 if (a0`i'==1|a0`i'==2|a0`i'==3)
}
*
recode num_livebirths 0=. if a0055==-2 & num_livebirths==0
*coded as missing cases where the entry for the first pregnancy is missing and there is no evidence of other children
label var num_livebirths "number of previous live births"

// BIRTH ORDER 
gen first_birth=1 if num_livebirths==0
replace first_birth=0 if num_livebirths>0 & num_livebirths!=.
label var first_birth "CM is first birth"

// SIBLINGS
gen num_siblings=0
foreach i in 5 9 13 17 21 25 29 33 37{
replace num_siblings=num_siblings+1 if (a4a_`i'>=11 &a4a_`i'<=14) 
}
*Older and younger brothers and sisters - not including adoptive & step

gen anysibling=1 if num_siblings>0&num_siblings!=.
replace anysibling=0 if num_siblings==0
replace anysibling=. if a4a_5==.

/*
// STEP AND ADOPTED SIBLINGS - not used in derivation of only child, included for info
gen num_stepsiblings=0
foreach i in 5 9 13 17 21 25 29 33 37{
replace num_stepsiblings=num_stepsiblings+1 if (a4a_`i'>=17 &a4a_`i'<=18) 
}

gen anystepsibling=1 if num_stepsiblings>0 & num_stepsibling!=.
replace anystepsibling=0 if num_stepsiblings==0
replace anystepsibling=. if a4a_5==.

gen num_adopsiblings=0
foreach i in 5 9 13 17 21 25 29 33 37{
replace num_adopsiblings=num_adopsiblings+1 if (a4a_`i'>=15 &a4a_`i'<=16) 
}

gen anyadopsibling=1 if num_adopsiblings>0 & num_adopsiblings!=.
replace anyadopsibling=0 if num_adopsiblings==0
replace anyadopsibling=. if a4a_5==.

tab1 anystepsibling num_stepsiblings anyadopsibling num_adopsiblings
*/

**********************
***** ONLY CHILD  ****
**********************


// ONLY CHILD (NO HALF OR FULL SIBLINGS)
gen onlychild=1 if anysibling==0
replace onlychild=0 if anysibling==1
recode onlychild 1=0 if first_birth==0
recode onlychild 1=0 if a0248==2|a0248==3 // recode if CM has twins/triplets
label variable onlychild "Sibling status - Analysis 1970"
label define onlychild 1 "Only" 0 "Sibling"
label values onlychild onlychild
tab onlychild 