/*______________________________________________________________________________

Millennium Cohort Study

Required datasets (UKDS SN & DOI to data edition): 
mcs1_derived_variables (SN 4683 http://doi.org/10.5255/UKDA-SN-4683-4)
mcs2_derived_variables (SN 5350 http://doi.org/10.5255/UKDA-SN-5350-4) 
mcs3_derived_variables (SN 5795 http://doi.org/10.5255/UKDA-SN-5795-4) 
mcs4_derived_variables (SN 6411 http://doi.org/10.5255/UKDA-SN-6411-7) 
mcs5_family_derived (SN 7464 http://doi.org/10.5255/UKDA-SN-7464-4)

______________________________________________________________________________*/


use mcs1_derived_variables.dta, clear
merge 1:1 MCSID using mcs2_derived_variables.dta, nogen
merge 1:1 MCSID using mcs3_derived_variables.dta, nogen
merge 1:1 MCSID using mcs4_derived_variables.dta, nogen
merge 1:1 MCSID using mcs5_family_derived.dta, nogen


*indicator of no parent interview since sweep 1
summ BDMINT00 BDPINT00 CDMINT00 CDPINT00 DDMINT00 DDPINT00 EDMINT00 EDPINT00
gen missingsw2_5= ((BDMINT00!=1 & BDPINT00!=1) & (CDMINT00!=1 & CDPINT00!=1) & (DDMINT00!=1 & DDPINT00!=1) & (EDMINT00!=1 & EDPINT00!=1))
tab missingsw2_5 // 1,930 cases have no full parent interview since sweep 1



// Identify CM who have a full sibling (including twin/triplets) - any sweep
gen full_sibling=(ADNSIB00==1|BDNSIB00==1|CDNSIB00==1|DDNSIB00==1|EDNSIB00==1)| ((ADNOCM00>1 & ADNOCM00!=.)|(BDNOCM00>1 & BDNOCM00!=.)|(CDNOCM00>1 & CDNOCM00!=.)|(DDNOCM00>1 & DDNOCM00!=.)|(EDNOCM00>1 & EDNOCM00!=.))

// Identify CM who have a half sibling
gen half_sibling=(ADHSIB00==1|BDHSIB00==1|CDHSIB00==1|DDHSIB00==1|EDHSIB00==1)

// Identify CM who have a step-sibling
gen step_sibling=(ADSSIB00==1|BDSSIB00==1|CDSSIB00==1|DDSSIB00==1|EDSSIB00==1)

// Identify CM who have an adopted sibling
gen adopted_sibling=(ADASIB00==1|BDASIB00==1|CDASIB00==1|DDASIB00==1|EDASIB00==1)

// Identify CM who have a foster sibling
gen foster_sibling=(ADFSIB00==1|BDFSIB00==1|CDFSIB00==1|DDFSIB00==1|EDFSIB00==1)
/*Sibling status DV excludes children with foster siblings*/

tab1 full_sibling half_sibling step_sibling adopted_sibling foster_sibling 

// ONLY CHILDREN (no co-resident sibling)
gen onlychild=1 if (full_sibling==0 & adopted_sibling==0 & half_sibling==0) & missingsw2_5==0 // set to only child if observe no siblings at any sweep (unless only observed sweep1)
replace onlychild=0 if (full_sibling==1 | adopted_sibling==1 | half_sibling==1) 
tab onlychild missingsw2_5, m

//Checks
*check step siblings
tab onlychild step_sibling if full_sibling==0 & adopted_sibling==0 & half_sibling==0 & missingsw2_5==0, m // 29 cases have only step sibling, we consider them as only children
*check foster siblings
tab onlychild foster_sibling
replace onlychild=. if foster_sibling==1 // drop 57 CM who have a foster sibling

label var onlychild "Sibling status"
label define onlychild 1 "Only" 0 "Sibling"
label values onlychild onlychild
tab onlychild 
