/*______________________________________________________________________________

National Child Development Study NCDS
Required datasets (UKDS SN DOI): 

ncds0123 (SN: 5565, http://doi.org/10.5255/UKDA-SN-5565-2)
______________________________________________________________________________*/


use ncds0123.dta, clear


gen num_births=n504 if n504>-1  // this is labelled parity in the dataset - question asked number of pregnancies including miscarriage 

// STILLBIRTHS (after 28 weeks of pregnancy (definition of still birth at that time - 28 weeks of pregnancy or less)
recode n508 -1=.
recode n508 1=0 2=1 3=2 4=3 5=4, gen (num_stillbirths)
gen stillbirth=1 if num_stillbirths>=1 & num_stillbirth!=.	
replace stillbirth=0 if num_stillbirths==0
label var stillbirth "Mother has had stillbirths"

// FIRST LIVE BIRTHS
gen first_birth=1 if num_births==1
replace first_birth=0 if num_births>1 & num_births!=.
replace first_birth=1 if num_births==2 & num_stillbirths==1
replace first_birth=1 if num_births==3 & num_stillbirths==2
replace first_birth=1 if num_births==4 & num_stillbirths==3
/*Had to recode as parity zero those whose number of births==number of stillbirths */ 
label var first_birth "CM is first live birth"

*Number of births the CM mother had after CM (age 11)
recode n1120 -1=.
gen subsequent_births=1 if n1120>=1 & n1120!=.
replace subsequent_births=0 if n1120==0

// SIBSHIP SIZE 
*Derive number of older siblings at time of CM birth
gen num_oldersibs=(n504-1) if n504>0 & n504!=.
replace num_oldersibs=(num_oldersibs-num_stillbirths)

*Derive number of younger siblings/cms
gen num_youngersibs=n1120

*Derive number of twins/triplets (set to 0 if CM doesn't have twins or triplets)
recode n1811 (-1/0=0)(1/2=1)(3/5=2), gen(numcms) 

*Derive sibship size
egen sibsize=rowtotal(num_oldersibs num_youngersibs numcms), missing // sum of younger siblings and older siblings
replace sibsize=. if (num_oldersibs==.|num_youngersibs==.) 
recode sibsize (0=1)(1=2)(2=3)(3/20=4)
label define sibsize 1"only child" 2"1 sibling" 3"2 siblings" 4"3+ siblings"
label values sibsize sibsize


**********************
***** ONLY CHILD *****
**********************

*ONLY CHILD age 11 (CM who are first births and whose mothers don't have subsequent births)
gen onlychild=1 if first_birth==1 & subsequent_births==0
replace onlychild=0 if first_birth==1 & subsequent_births==1
replace onlychild=0 if first_birth==0 & first_birth!=.
recode onlychild 1=0 if n1811>0 & n1811!=. // recode CM who have twins
recode onlychild .=0 if n1811>0 & n1811!=. // recode CM who have twins
label variable onlychild "Sibling status - Analysis 1958"
label define onlychild 1 "Only" 0 "Sibling"

*CM who have younger siblings at age 16 interview (with same mother as CM)
recode n2368 -1=.
recode n2370 -1=.

*Any younger sibling at age 16 interview (with same mother as CM)
gen youngersiblings=0 if n2368==0&n2370==0
recode youngersiblings .=1 if n2368!=.|n2370!=.

*Number of younger siblings at age 16 interview (merge 3 or more siblings together)
gen number_youngersiblings=n2368+n2370
recode number_youngersiblings 4=3 5=3 6=3 7=3 8=3 9=3 10=3  

*Any older sibling at age 16 interview (with same mother as CM)
recode n2369 -1=.
recode n2367 -1=.
gen oldersiblings=0 if n2369==0&n2367==0
recode oldersiblings .=1 if n2369!=.|n2367!=.

*Number of older siblings at age 16 interview
gen num_oldersiblings=n2369+n2367
recode oldersiblings .=1 if n2369!=.|n2367!=.

*number of siblings age 16
egen number_sibs16=rowtotal (n2368 n2370 n2369 n2367), missing
recode number_sibs16 3/14=3

*ONLY CHILD age 16 (CM who don't have younger or older siblings at age 16 interview)
gen onlychild16=1 if oldersibling==0 & youngersiblings==0
replace onlychild16=0 if oldersibling==1 | youngersiblings==1

**recoding of ONLY CHILD age 11 based on information provided by age 16 interview for those who had missing information on subsequent birth question & had younger siblings
recode onlychild .=0 if onlychild16==0 & youngersibling>=1 & youngersibling!=. & subsequent_births==. // 389 cases (missing at age 11 because of missing data on the subsequent birth question)
tab onlychild, m // 947 only children
tab sibsize onlychild , m
replace onlychild=. if sibsize==. // set missings consistent across two indicators
tab onlychild // 947 only children

